# My Package

wyl-tools
===============


* 常用函数的封装，方便日常快速开发

Target Users
--------------

* data analyst of China


Installation
--------------

    pip install wyl-tools

Upgrade
---------------

    pip install wyl-tools --upgrade

Quick Start
--------------

::

    import kjj as KjjApi
    api = KjjApi("your token")
    




